import { Component, Inject, OnInit } from '@angular/core';
import { MAT_DIALOG_DATA, MatDialogRef } from "@angular/material/dialog";
import { MatTableDataSource } from "@angular/material/table";
import { ConfigService } from "@services/config.service";
import { HttpClient } from "@angular/common/http";
import { ToastrService } from "ngx-toastr";

@Component({
  selector: 'app-boot-so-partition',
  templateUrl: './boot-so-partition.component.html',
  styleUrl: './boot-so-partition.component.css'
})
export class BootSoPartitionComponent implements OnInit {
  baseUrl: string;
  selectedPartition: any = null;
  dataSource = new MatTableDataSource<any>();
  clientId: string | null = null;
  selectedClients: any[] = [];
  selectedModelClient: any = null;
  filteredPartitions: any[] = [];
  allSelected: boolean = false;
  clientData: any[] = [];
  loading: boolean = false;
  columns = [
    {
      columnDef: 'diskNumber',
      header: 'Disco',
      cell: (partition: any) => partition.diskNumber
    },
    {
      columnDef: 'partitionNumber',
      header: 'Particion',
      cell: (partition: any) => partition.partitionNumber
    },
    {
      columnDef: 'size',
      header: 'Tamaño',
      cell: (partition: any) => `${partition.size} MB`
    },
    {
      columnDef: 'partitionCode',
      header: 'Tipo de partición',
      cell: (partition: any) => partition.partitionCode
    },
    {
      columnDef: 'filesystem',
      header: 'Sistema de ficheros',
      cell: (partition: any) => partition.filesystem
    },
    {
      columnDef: 'operativeSystem',
      header: 'SO',
      cell: (partition: any) => partition.operativeSystem?.name
    }
  ];

  displayedColumns = ['select', ...this.columns.map(column => column.columnDef)];

  constructor(
    @Inject(MAT_DIALOG_DATA) public data: { clients: any },
    private dialogRef: MatDialogRef<BootSoPartitionComponent>,
    private configService: ConfigService,
    private http: HttpClient,
    private toastService: ToastrService,
  ) {
    this.baseUrl = this.configService.apiUrl;
    this.clientId = this.data.clients?.length ? this.data.clients[0]['@id'] : null;

    this.data.clients.forEach((client: { selected: boolean; status: string }) => {
      if (client.status === 'og-live') {
        client.selected = true;
      }
    });

    this.selectedClients = this.data.clients.filter(
      (client: { status: string }) => client.status === 'og-live'
    );

    this.selectedModelClient = this.data.clients.find(
      (client: { status: string }) => client.status === 'og-live'
    ) || null;

    if (this.selectedModelClient) {
      this.loadPartitions(this.selectedModelClient);
    }
  }

  ngOnInit() {

  }

  loadPartitions(client: any) {
    const url = `${this.baseUrl}${client.uuid}`;
    this.http.get(url).subscribe(
      (response: any) => {
        if (response.partitions) {
          this.dataSource.data = response.partitions.filter((partition: any) => {
            return partition.partitionNumber !== 0;
          });
        }
      },
      (error) => {
        console.error('Error al cargar los datos del cliente:', error);
      }
    );
  }

  toggleClientSelection(client: any) {
    client.selected = !client.selected;
    this.updateSelectedClients();
  }

  updateSelectedClients() {
    this.selectedClients = this.data.clients.filter(
      (client: { selected: boolean; state: string }) => client.selected && client.state === "og-live"
    );

    if (!this.selectedClients.includes(this.selectedModelClient)) {
      this.selectedModelClient = null;
      this.filteredPartitions = [];
    }
  }

  toggleSelectAll() {
    this.allSelected = !this.allSelected;
    this.data.clients.forEach((client: { selected: boolean; status: string }) => {
      if (client.status === "og-live") {
        client.selected = this.allSelected;
      }
    });
  }

  close() {
    this.dialogRef.close();
  }

  execute(): void {
    this.loading = true;
    this.http.post(`${this.baseUrl}/clients/server/boot-client`, {
      clients: this.selectedClients.map((client: any) => client.uuid),
      partition: this.selectedPartition['@id']
    }).subscribe(
      response => {
        this.toastService.success('Cliente actualizado correctamente');
        this.dialogRef.close();
        this.loading = false;
      },
      error => {
        this.toastService.error(error.error['hydra:description']);
        this.loading = false;
      }
    );
  }
}
