import { Component, EventEmitter, OnInit, Output } from '@angular/core';
import { ChangePasswordModalComponent } from '../../components/admin/users/users/change-password-modal/change-password-modal.component';
import { MatDialog } from "@angular/material/dialog";
import { GlobalStatusComponent } from 'src/app/components/global-status/global-status.component';
import { BreakpointObserver } from '@angular/cdk/layout';
import { AuthService } from '@services/auth.service';

@Component({
  selector: 'app-header',
  templateUrl: './header.component.html',
  styleUrls: ['./header.component.css'],
})

export class HeaderComponent implements OnInit {
  isSuperAdmin: boolean = false;
  isSmallScreen: boolean = false;

  @Output() toggleSidebar = new EventEmitter<void>();

  onToggleSidebar() {
    this.toggleSidebar.emit();
  }

  constructor(
    public dialog: MatDialog,
    public auth: AuthService,
    private breakpointObserver: BreakpointObserver
  ) { }

  ngOnInit(): void {
    this.breakpointObserver.observe(['(max-width: 576px)']).subscribe((result) => {
      this.isSmallScreen = result.matches;
    })
  }

  editUser() {
    const dialogRef = this.dialog.open(ChangePasswordModalComponent, {
      data: { user: this.auth.username, uuid: this.auth.uuid },
      width: '400px',
    });
  }

  showGlobalStatus() {
    this.dialog.open(GlobalStatusComponent, {
      width: '45vw',
      height: '80vh',
    })
  }

  logOut() {
    this.auth.logout();
  }
}
